/*========================================================================
     "gpop7ctr"  Gaussian output post processor - 7 coordinate transform
 (this is for very specific use)
             Copyright (c) 2002-2013 by A. Miyoshi, Univ. Tokyo
                                     created: Dec.   2, 2004
                                      edited: Nov.  19, 2007
========================================================================*/

#include "gpoplibc.h"

/*===== main function ==================================================*/

int main(int argc, char *argv[]) {
  int ir, ia, ic, prec;
  string basfln;
  jobInfos jbinf;
  molecGeom molc;
  freqTable frtab;
  matrxCart tranMat;
  coordCart trncc, devcc;
  coordPolar trncp, devcp;
  vector<coordCart> tranCrdC;
  vector<coordPolar> tranCrdP;

  showRevision();
  if (argc != 2)
    { cout << "usage: gpop7ctr basnam\n"; return 1; }
  basfln = argv[1];

  // --- read in gpop (.gpo) file
  if (readGpo(basfln, jbinf, molc, frtab) == ERRE) { return 1; }

  // --- transform
  molc.geom.setPrcAxesMomInert();
  for (ir = 0; ir < 3; ir++) { tranMat[ir] = molc.geom.prcAxes[ir]; }
  cout << "coordinates:\n" << "i an x y z r th ph\n";
  for (ia = 0; ia < molc.nAtms; ia++) {
    trncc = transCoord(molc.geom[ia], tranMat, molc.geom.com);
    trncp.setFrom(trncc);
    tranCrdC.push_back(trncc); tranCrdP.push_back(trncp);
    cout << ia + 1 << " " << molc.geom[ia].atomicNumber;
    prec = cout.precision(); cout.setf(ios::fixed); cout.precision(6);
    for (ic = 0; ic < 3; ic++) { cout << " " << trncc[ic]; }
    cout << " " << trncp.r; cout.precision(4);
    cout << " " << trncp.degTh() << " " << trncp.degPh();
    cout.unsetf(ios::fixed); cout.precision(prec); cout << endl;
  }
  cout << "mode-0 deviations:\n" << "i an x y z r th ph\n";
  for (ia = 0; ia < molc.nAtms; ia++) {
    devcc = tranMat * frtab[0].nrm[ia];
    trncc = tranCrdC[ia] + 0.1 * devcc;
    trncp.setFrom(trncc);
    devcp = trncp - tranCrdP[ia];
    cout << ia + 1 << " " << molc.geom[ia].atomicNumber;
    prec = cout.precision(); cout.setf(ios::fixed); cout.precision(6);
    for (ic = 0; ic < 3; ic++) { cout << " " << devcc[ic]; }
    cout << " " << devcp.r; cout.precision(4);
    cout << " " << devcp.degTh() << " " << devcp.degPh();
    cout.unsetf(ios::fixed); cout.precision(prec); cout << endl;
  }

  return 0;
}

