/*========================================================================
     This is a part of "gpop" - Gaussian output post processor
             Copyright (c) 2002-2020 by A. Miyoshi, Hiroshima Univ.
========================================================================*/

#ifndef _GPOPLIBF_H_
#define _GPOPLIBF_H_

#ifndef _CRT_SECURE_NO_WARNINGS
#define _CRT_SECURE_NO_WARNINGS
#endif

#include <iostream>
#include <fstream>
#include <sstream>
#include <iomanip>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <float.h>
#include <cctype>
#include <cstring>
#include <cstdlib>
#include <cmath>
#include "lapack_dsyev/wcpp_dsyev.h"
using namespace std;

#ifndef true
#define true (-1)
#endif
#ifndef false
#define false 0
#endif
#ifndef M_PI
#define	M_PI    3.14159265358979323846
#endif
#define NORM 0
#define ERRE 1
#define IX   0
#define IY   1
#define IZ   2
#define MAXLN1L 4096
#define MAXSMAT 10
#define GAUCPRC 0.000001
#define GPOPREV "GPOP rev. 2013.07.15m10"
#define ENVLIB  "GPOP_LIB"         // library environment variable name
#define FLMLIB  "methods.dat"      // method library file name

/* ----- Below is based on CODATA 2010 Physical Constants ----- */

#define ANGBOHR 0.52917721092      // Bohr radius in Angstrom
#define WAVNHRT 219474.6314        // cm-1 hartree-1
#define KJMLHRT 2625.499641        // kJ/mol hartree-1
#define KCAMHRT 627.5094744        // kcal/mol hartree-1
#define BIGHAA2 505.379009         // GHz amu A2
#define BIWAA2  16.8576292         // cm-1 amu A2
#define GHZWAVN 29.9792458         // GHz (cm-1)-1
#define KELWAVN 1.438776968        // K (cm-1)-1
#define JMLWAVN 11.96265657        // J mol-1 (cm-1)-1
#define RGASC   8.3144621          // J K-1 mol-1
#define STDTMPR 298.15             // standard ambient temperature
#define RBCMMLC 1.380648792e-22    // bar K-1 cm3 molecule-1
#define CTRANS  1.87931787e+20     // coefficient for q(trans)
#define CSTR1B  (-1.151707782)     // constant part of S(trans)@1bar
#define TSTK_H  2.083661781e+10    // kB/h

/*----- generic library funtions ---------------------------------------*/

void showRevision();
string getBasePart(string flname);
string getExtPart(string flname);
int getLine(istream &inStrm, string &sLine);
int getLineTrim(istream &inStrm, string &sLine);
int getLineRmCmm(istream &inStrm, string &sLine, const string &cmmSyms);
int skipLines(istream &inStrm, int nLines);
int skipGetLine(istream &inStrm, int nLines, string &sLine);
int skipLinesToKey(istream &inStrm, string &sLine, const string &sKey);
void strAllToUpper(string &s);
void strAllToLower(string &s);
string ltrim(string s);
string rtrim(string s);
string trim(string s);
vector<string> splitTokens(string &s, const string &spr);
string format(int v);
string format(int v, int len, char filc);
string formatF(double v, int len, int prc);
string strListIdx(vector<int> &lst);

#endif

