# ========================================================================
#    This is a part of "gpop" - Gaussian output post processor
#            Copyright (c) 2002-2012 by A. Miyoshi, Univ. Tokyo
#                      last edited: June   2, 2013
# ========================================================================

# --- make gpop - Gaussian output post processor -----------------------
#  gpop1scf: read Gaussian SCF-freq job output and create a .gpo file
#  gpop2mlp: read MOLPTO frequency job output and create a .gpo file
#  gpop3atm: create .gpo data for atomic species
#  gpop3tst: modification of .gpo data for thermo and TST calculations
#  gpop4thf: calculate thermodynamic functions
#  gpop5vib: create animation file (for FreeWheel) of vibrational modes
#  gpop6irt: calculate reduced moment of inertia of a internal rotor
#  gpop6mrt: calculation for coupler internal rotors
#  tstrate:  TST rate constant and equilibrium const. calculation
#  vtst:     VTST calculation
#  introt:   similar to gpop6mrt but for non-GPOP format file
#  prepum:   creates UNOMOL RRKM input
# ----------------------------------------------------------------------

# ----- 'remove', 'mv' and 'ar' commands -------------------------------

#RM = rm -f
RM = del
#MV = mv
MV = move
#AR = ar cr 
AR = lib /OUT:

# ----- file name extensions of object/archive files -------------------

#XOBJ = o
XOBJ = obj
#XARC = a
XARC = lib

# ----- names of C++ and Fortran compilers and options -----------------
# ----- suggested names of C++ and Fortran compilers
#  GNU compiler (version 4)         .. g++, gfortran
#               (version 3)         .. g++, g77
#  Intel compilers for Linux/MacOS  .. icc, ifort
#                  for Windows      .. icl, ifort
# ----- suggested optimization flags
#  Intel compilers for Windows      .. -O2
#  Others                           .. -O
# ----------------------------------------------------------------------

#CPCMP = g++ -O
#CPCMP = icc -O
CPCMP = icl -O2

#F7CMP = gfortran -O
#F7CMP = g77 -O
#F7CMP = ifort -O
F7CMP = ifort -O2

# ----- name of the LAPACK/BLAS library file ---------------------------
#  to build a part of LAPACK/BLAS:   .. lapack_*.$(XARC)
#  to link pre-build LAPACK/BLAS:    .. wcpp_*.$(XOBJ)
# ----------------------------------------------------------------------

FLPKSE = lapack_dsyev.$(XARC)
#FLPKSE = wcpp_dsyev.$(XOBJ)
LPKPOS = lapack_dposv.$(XARC)
#LPKPOS = wcpp_dposv.$(XOBJ)

# ----- program to be used for linking ---------------------------------

LNKER = $(CPCMP)
#LNKER = $(F7CMP) -nofor_main

# ----- library options to the linker ----------------------------------
#  when FLPKSE/LPKPOS != (null)
#   GNU compiler (gfortran)         .. -lgfortran
#                (g77)              .. -lg2c
#   Intel compilers for Linux       .. -cxxlib
#   Intel compilers for Windows     .. (null)
#  when FLPKSE/LPKPOS == (null)
#   BLAS/LAPACK (gfortran-built)    .. -llapack -lblas -lgfortran
#               (g77-built)         .. -llapack -lblas -lg2c
#   intel MKL                       .. (consult the MKL manual)
# ----------------------------------------------------------------------

#LLIBS = -lgfortran
#LLIBS = -lg2c
#LLIBS = -cxxlib
LLIBS =
#LLIBS = -llapack -lblas -lgfortran
#LLIBS = -llapack -lblas -lg2c
#LLIBS = -lmkl_em64t -lguide -lpthread -cxxlib
#LLIBS = -lmkl_lapack -lmkl_em64t -lguide -lpthread -cxxlib
#LLIBS = mkl_intel_c.lib mkl_intel_thread.lib mkl_core.lib libiomp5mt.lib

# ===== no need to edit below in usual circumstances =====================

LIBOBJ = gpoplibc.$(XOBJ) gpoplibf.$(XOBJ) $(FLPKSE)
LIBAOBJ = numlibArf.$(XOBJ) numlibBls.$(XOBJ) $(LPKPOS)
LIBROBJ = gpoplibr.$(XOBJ) $(LIBOBJ)
LIBTOBJ = gpoplibt.$(XOBJ) $(LIBROBJ) $(LIBAOBJ)
LIBUOBJ = gpoplibu.$(XOBJ) $(LIBTOBJ)
HEADS = gpoplibc.h gpoplibf.h lapack_dsyev/wcpp_dsyev.h
HEADAR = numlibArf.h numlibBls.h lapack_dposv/wcpp_dposv.h
HEADSR = gpoplibr.h $(HEADS)
HEADST = gpoplibt.h $(HEADSR) $(HEADAR)
HEADSU = gpoplibu.h $(HEADST)

all: gpop1scf gpop2mlp gpop3atm gpop3tst gpop4thf gpop5vib \
     gpop6irt gpop6mrt tstrate vtst introt prepum pac99 c97to7

gpop1scf : gpop1scf.$(XOBJ) $(LIBOBJ)
	$(LNKER) gpop1scf.$(XOBJ) $(LIBOBJ) $(LLIBS) -o gpop1scf

gpop2mlp : gpop2mlp.$(XOBJ) $(LIBOBJ)
	$(LNKER) gpop2mlp.$(XOBJ) $(LIBOBJ) $(LLIBS) -o gpop2mlp

gpop3atm : gpop3atm.$(XOBJ) $(LIBTOBJ)
	$(LNKER) gpop3atm.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o gpop3atm

gpop3tst : gpop3tst.$(XOBJ) $(LIBTOBJ)
	$(LNKER) gpop3tst.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o gpop3tst

gpop3mod : gpop3mod.$(XOBJ) $(LIBTOBJ)
	$(LNKER) gpop3mod.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o gpop3mod

gpop4thf : gpop4thf.$(XOBJ) $(LIBTOBJ)
	$(LNKER) gpop4thf.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o gpop4thf

gpop5vib : gpop5vib.$(XOBJ) $(LIBOBJ)
	$(LNKER) gpop5vib.$(XOBJ) $(LIBOBJ) $(LLIBS) -o gpop5vib

gpop6irt : gpop6irt.$(XOBJ) $(LIBOBJ)
	$(LNKER) gpop6irt.$(XOBJ) $(LIBOBJ) $(LLIBS) -o gpop6irt

gpop6mrt : gpop6mrt.$(XOBJ) $(LIBROBJ)
	$(LNKER) gpop6mrt.$(XOBJ) $(LIBROBJ) $(LLIBS) -o gpop6mrt

gpop7ctr : gpop7ctr.$(XOBJ) $(LIBOBJ)
	$(LNKER) gpop7ctr.$(XOBJ) $(LIBOBJ) $(LLIBS) -o gpop7ctr

tstrate : tstrate.$(XOBJ) $(LIBTOBJ)
	$(LNKER) tstrate.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o tstrate

vtst : vtst.$(XOBJ) $(LIBTOBJ) spline.$(XOBJ)
	$(LNKER) vtst.$(XOBJ) $(LIBTOBJ) spline.$(XOBJ) $(LLIBS) -o vtst

introt : introt.$(XOBJ) $(LIBTOBJ)
	$(LNKER) introt.$(XOBJ) $(LIBTOBJ) $(LLIBS) -o introt

prepum : prepum.$(XOBJ) $(LIBUOBJ)
	$(LNKER) prepum.$(XOBJ) $(LIBUOBJ) $(LLIBS) -o prepum

gpop1scf.$(XOBJ) : gpop1scf.cc gpop1scf.h $(HEADS)
	$(CPCMP) -c gpop1scf.cc

gpop2mlp.$(XOBJ) : gpop2mlp.cc gpop2mlp.h $(HEADS)
	$(CPCMP) -c gpop2mlp.cc

gpop3atm.$(XOBJ) : gpop3atm.cc $(HEADST)
	$(CPCMP) -c gpop3atm.cc

gpop3tst.$(XOBJ) : gpop3tst.cc $(HEADST)
	$(CPCMP) -c gpop3tst.cc

gpop3mod.$(XOBJ) : gpop3mod.cc $(HEADST)
	$(CPCMP) -c gpop3mod.cc

gpop4thf.$(XOBJ) : gpop4thf.cc $(HEADST)
	$(CPCMP) -c gpop4thf.cc

gpop5vib.$(XOBJ) : gpop5vib.cc $(HEADS)
	$(CPCMP) -c gpop5vib.cc

gpop6irt.$(XOBJ) : gpop6irt.cc $(HEADS)
	$(CPCMP) -c gpop6irt.cc

gpop6mrt.$(XOBJ) : gpop6mrt.cc $(HEADSR)
	$(CPCMP) -c gpop6mrt.cc

gpop7ctr.$(XOBJ) : gpop7ctr.cc $(HEADS)
	$(CPCMP) -c gpop7ctr.cc

tstrate.$(XOBJ) : tstrate.cc $(HEADST)
	$(CPCMP) -c tstrate.cc

vtst.$(XOBJ) : vtst.cc vtst.h spline.h $(HEADST)
	$(CPCMP) -c vtst.cc

introt.$(XOBJ) : introt.cc $(HEADST)
	$(CPCMP) -c introt.cc

prepum.$(XOBJ) : prepum.cc $(HEADSU)
	$(CPCMP) -c prepum.cc

gpoplibu.$(XOBJ) : gpoplibu.cc $(HEADSU)
	$(CPCMP) -c gpoplibu.cc

gpoplibt.$(XOBJ) : gpoplibt.cc $(HEADST)
	$(CPCMP) -c gpoplibt.cc

gpoplibr.$(XOBJ) : gpoplibr.cc $(HEADSR)
	$(CPCMP) -c gpoplibr.cc

gpoplibc.$(XOBJ) : gpoplibc.cc $(HEADS)
	$(CPCMP) -c gpoplibc.cc

gpoplibf.$(XOBJ) : gpoplibf.cc gpoplibf.h
	$(CPCMP) -c gpoplibf.cc

spline.$(XOBJ) : spline.cc spline.h
	$(CPCMP) -c spline.cc

numlibArf.$(XOBJ) : numlibArf.cc $(HEADAR)
	$(CPCMP) -c numlibArf.cc

numlibBls.$(XOBJ) : numlibBls.cc numlibBls.h lapack_dposv/wcpp_dposv.h
	$(CPCMP) -c numlibBls.cc

lapack_dsyev.$(XARC) : lapack_dsyev/wcpp_dsyev.cc lapack_dsyev/*.f
	cd lapack_dsyev && \
	$(CPCMP) -c wcpp_dsyev.cc && \
	$(F7CMP) -c *.f && \
	$(AR)../$(FLPKSE) *.$(XOBJ) && \
	$(RM) *.$(XOBJ) && \
	cd ..

wcpp_dsyev.$(XOBJ) : lapack_dsyev/wcpp_dsyev.cc
	cd lapack_dsyev && \
	$(CPCMP) -c wcpp_dsyev.cc && \
	$(MV) wcpp_dsyev.$(XOBJ) ../ && \
	cd ..

lapack_dposv.$(XARC) : lapack_dposv/wcpp_dposv.cc lapack_dposv/*.f
	cd lapack_dposv && \
	$(CPCMP) -c wcpp_dposv.cc && \
	$(F7CMP) -c *.f && \
	$(AR)../$(LPKPOS) *.$(XOBJ) && \
	$(RM) *.$(XOBJ) && \
	cd ..

wcpp_dposv.$(XOBJ) : lapack_dposv/wcpp_dposv.cc
	cd lapack_dposv && \
	$(CPCMP) -c wcpp_dposv.cc && \
	$(MV) wcpp_dposv.$(XOBJ) ../ && \
	cd ..

pac99 : pac/pac99.f
c97to7 : pac/c97to7.f
	cd pac && \
	$(F7CMP) pac99.f -o ../pac99 && \
	$(F7CMP) c97to7.f -o ../c97to7 && \
	$(RM) *.$(XOBJ) && \
	cd ..

clean:
	$(RM) *.$(XOBJ) *.$(XARC)

